# Lytix Client Python Packages

This directory contains all the python packages for the Lytix project.

#### Environment Variables

The following environment variables are required to run the Lytix client.

- `LX_API_KEY`: The API key for the Lytix API. This is required to send data to the Lytix API.

The followig environment variables are optional.

- `LX_BASE_URL`: The base URL for the Lytix API. This is required to send data to the Lytix API.
